@@ -383,7 +383,7 @@ def combine_sample_regions(*samples):
     out = []
     analysis_files = []
     with shared.bedtools_tmpdir(samples[0]):
-        for batch, items in vmulti.group_by_batch(samples).items():
+        for batch, items in vmulti.group_by_batch(samples, require_bam=False).items():
             if global_analysis_file:
                 analysis_file, no_analysis_file = global_analysis_file, global_no_analysis_file
             else:
@@ -397,6 +397,11 @@ def combine_sample_regions(*samples):
                     data["config"]["algorithm"]["callable_count"] = pybedtools.BedTool(analysis_file).count()
                 elif vr_file:
                     data["config"]["algorithm"]["callable_count"] = pybedtools.BedTool(vr_file).count()
+                # attach a representative sample for calculating callable region
+                if not data.get("work_bam"):
+                    for x in items:
+                        if x.get("work_bam"):
+                            data["work_bam_callable"] = x["work_bam"]
                 out.append([data])
         assert len(out) == len(samples)
         if len(analysis_files) > 0:
@@ -429,7 +434,7 @@ def _combine_sample_regions_batch(batch, items):
                 min_n_size = int(config["algorithm"].get("nomap_split_size", 100))
                 block_filter = NBlockRegionPicker(ref_regions, config)
                 final_nblock_regions = nblock_regions.filter(
-                    block_filter.include_block).each(block_filter.expand_block).saveas(
+                    block_filter.include_block).saveas().each(block_filter.expand_block).saveas(
                         "%s-nblockfinal%s" % utils.splitext_plus(tx_afile))
                 final_regions = ref_regions.subtract(final_nblock_regions).merge(d=min_n_size)
                 _write_bed_regions(items[0], final_regions, tx_afile, tx_noafile)
