@@ -162,6 +162,25 @@ def run_cufflinks(*args):
     with _setup_logging(args) as config:
         return ipython.zip_args(apply(rnaseq.run_cufflinks, *args))
 
+@require(rnaseq)
+def run_rnaseq_variant_calling(*args):
+    args = ipython.unzip_args(args)
+    with _setup_logging(args) as config:
+        return ipython.zip_args(apply(rnaseq.run_rnaseq_variant_calling, *args))
+
+@require(rnaseq)
+def run_express(*args):
+    args = ipython.unzip_args(args)
+    with _setup_logging(args) as config:
+        return ipython.zip_args(apply(rnaseq.run_express, *args))
+
+@require(rnaseq)
+def run_dexseq(*args):
+    args = ipython.unzip_args(args)
+    with _setup_logging(args) as config:
+        return ipython.zip_args(apply(rnaseq.run_dexseq, *args))
+
+
 @require(shared)
 def combine_bam(*args):
     args = ipython.unzip_args(args)
@@ -234,6 +253,12 @@ def run_disambiguate(*args):
     with _setup_logging(args) as config:
         return ipython.zip_args(apply(disambiguate.run, *args))
 
+@require(disambiguate)
+def disambiguate_split(*args):
+    args = ipython.unzip_args(args)
+    with _setup_logging(args) as config:
+        return ipython.zip_args(apply(disambiguate.split, *args))
+
 @require(system)
 def machine_info(*args):
     args = ipython.unzip_args(args)
