@@ -2,7 +2,7 @@
 """
 from bcbio import structural, utils, chipseq
 from bcbio.bam import callable
-from bcbio.rnaseq import sailfish
+from bcbio.rnaseq import (sailfish, express)
 from bcbio.ngsalign import alignprep
 from bcbio.pipeline import (archive, disambiguate, qcsummary, sample,
                             main, shared, variation, run_info, rnaseq)
@@ -78,6 +78,18 @@ def generate_transcript_counts(*args):
 def run_cufflinks(*args):
     return rnaseq.run_cufflinks(*args)
 
+@utils.map_wrap
+def run_express(*args):
+    return rnaseq.run_express(*args)
+
+@utils.map_wrap
+def run_dexseq(*args):
+    return rnaseq.run_dexseq(*args)
+
+@utils.map_wrap
+def run_rnaseq_variant_calling(*args):
+    return rnaseq.run_rnaseq_variant_calling(*args)
+
 @utils.map_wrap
 def combine_bam(*args):
     return shared.combine_bam(*args)
@@ -134,6 +146,10 @@ def coverage_summary(*args):
 def run_disambiguate(*args):
     return disambiguate.run(*args)
 
+@utils.map_wrap
+def disambiguate_split(*args):
+    return disambiguate.split(*args)
+
 @utils.map_wrap
 def clean_chipseq_alignment(*args):
     return chipseq.clean_chipseq_alignment(*args)
