@@ -14,17 +14,20 @@ from bcbio.log import logger
 from bcbio.distributed.multi import run_multicore, zeromq_aware_logging
 from bcbio.distributed.transaction import file_transaction
 from bcbio.pipeline import config_utils, tools
+from bcbio.pipeline import datadict as dd
 from bcbio.provenance import do
 
 def create_inputs(data):
     """Index input reads and prepare groups of reads to process concurrently.
 
     Allows parallelization of alignment beyond processors available on a single
-    machine. Uses gbzip and grabix to prepare an indexed fastq file.
+    machine. Uses bgzip and grabix to prepare an indexed fastq file.
     """
     aligner = tz.get_in(("config", "algorithm", "aligner"), data)
-    # CRAM files must be converted to bgzipped fastq, unless not aligning
-    if not ("files" in data and _is_cram_input(data["files"]) and aligner):
+    # CRAM files must be converted to bgzipped fastq, unless not aligning.
+    # Also need to prep and download remote files.
+    if not ("files" in data and aligner and (_is_cram_input(data["files"]) or
+                                             _is_remote_input(data["files"]))):
         # skip indexing on samples without input files or not doing alignment
         if ("files" not in data or data["files"][0] is None or
               data["config"]["algorithm"].get("align_split_size") is None
@@ -143,6 +146,9 @@ def _is_bam_input(in_files):
 def _is_cram_input(in_files):
     return in_files[0].endswith(".cram") and (len(in_files) == 1 or in_files[1] is None)
 
+def _is_remote_input(in_files):
+    return in_files[0].startswith(utils.SUPPORTED_REMOTES)
+
 def _prep_grabix_indexes(in_files, dirs, data):
     if _is_bam_input(in_files):
         out = _bgzip_from_bam(in_files[0], dirs, data["config"])
@@ -194,6 +200,24 @@ def _bgzip_from_cram(cram_file, dirs, data):
         assert utils.file_exists(out_s)
         return [out_s]
 
+def _bgzip_from_cram_sambamba(cram_file, dirs, data):
+    """Use sambamba to extract from CRAM via regions.
+    """
+    raise NotImplementedError("sambamba doesn't yet support retrieval from CRAM by BED file")
+    region_file = (tz.get_in(["config", "algorithm", "variant_regions"], data)
+                   if tz.get_in(["config", "algorithm", "coverage_interval"], data) in ["regional", "exome"]
+                   else None)
+    base_name = utils.splitext_plus(os.path.basename(cram_file))[0]
+    work_dir = utils.safe_makedir(os.path.join(dirs["work"], "align_prep",
+                                               "%s-parts" % base_name))
+    f1, f2, o1, o2, si = [os.path.join(work_dir, "%s.fq" % x) for x in ["match1", "match2", "unmatch1", "unmatch2",
+                                                                        "single"]]
+    ref_file = dd.get_ref_file(data)
+    region = "-L %s" % region_file if region_file else ""
+    cmd = ("sambamba view -f bam -l 0 -C {cram_file} -T {ref_file} {region} | "
+           "bamtofastq F={f1} F2={f2} S={si} O={o1} O2={o2}")
+    do.run(cmd.format(**locals()), "Convert CRAM to fastq in regions")
+
 def _merge_and_bgzip(orig_files, out_file, base_file, ext=""):
     """Merge a group of gzipped input files into a final bgzipped output.
 
@@ -245,16 +269,17 @@ def _cram_to_fastq_region(cram_file, work_dir, base_name, region, data):
     cores = tz.get_in(["config", "algorithm", "num_cores"], data, 1)
     max_mem = int(resources.get("memory", "1073741824")) * cores  # 1Gb/core default
     rext = "-%s" % region.replace(":", "_").replace("-", "_") if region else "full"
-    out_s, out_p1, out_p2 = [os.path.join(work_dir, "%s%s-%s.fq.gz" %
-                                          (base_name, rext, fext))
-                             for fext in ["s1", "p1", "p2"]]
+    out_s, out_p1, out_p2, out_o1, out_o2 = [os.path.join(work_dir, "%s%s-%s.fq.gz" %
+                                                          (base_name, rext, fext))
+                                             for fext in ["s1", "p1", "p2", "o1", "o2"]]
     if not utils.file_exists(out_p1):
-        with file_transaction(data, out_s, out_p1, out_p2) as (tx_out_s, tx_out_p1, tx_out_p2):
+        with file_transaction(data, out_s, out_p1, out_p2, out_o1, out_o2) as \
+             (tx_out_s, tx_out_p1, tx_out_p2, tx_out_o1, tx_out_o2):
             cram_file = utils.remote_cl_input(cram_file)
             sortprefix = "%s-sort" % utils.splitext_plus(tx_out_s)[0]
             cmd = ("bamtofastq filename={cram_file} inputformat=cram T={sortprefix} "
-                   "gz=1 collate=1 colsbs={max_mem} "
-                   "F={tx_out_p1} F2={tx_out_p2} S={tx_out_s} O=/dev/null O2=/dev/null "
+                   "gz=1 collate=1 colsbs={max_mem} exclude=SECONDARY,SUPPLEMENTARY "
+                   "F={tx_out_p1} F2={tx_out_p2} S={tx_out_s} O={tx_out_o1} O2={tx_out_o2} "
                    "reference={ref_file}")
             if region:
                 cmd += " ranges='{region}'"
@@ -322,8 +347,9 @@ def _grabix_index(data):
     config = data["config"]
     grabix = config_utils.get_program("grabix", config)
     gbi_file = in_file + ".gbi"
-    if not utils.file_exists(gbi_file) or _is_partial_index(gbi_file):
-        do.run([grabix, "index", in_file], "Index input with grabix: %s" % os.path.basename(in_file))
+    if tz.get_in(["algorithm", "align_split_size"], config):
+        if not utils.file_exists(gbi_file) or _is_partial_index(gbi_file):
+            do.run([grabix, "index", in_file], "Index input with grabix: %s" % os.path.basename(in_file))
     return [gbi_file]
 
 def _is_partial_index(gbi_file):
@@ -346,9 +372,11 @@ def _bgzip_from_fastq(data):
     needs_convert = config["algorithm"].get("quality_format", "").lower() == "illumina"
     if in_file.endswith(".gz") and not in_file.startswith(utils.SUPPORTED_REMOTES):
         needs_bgzip, needs_gunzip = _check_gzipped_input(in_file, grabix, needs_convert)
+    elif in_file.startswith(utils.SUPPORTED_REMOTES) and not tz.get_in(["algorithm", "align_split_size"], config):
+        needs_bgzip, needs_gunzip = False, False
     else:
         needs_bgzip, needs_gunzip = True, False
-    if needs_bgzip or needs_gunzip or needs_convert:
+    if needs_bgzip or needs_gunzip or needs_convert or in_file.startswith(utils.SUPPORTED_REMOTES):
         out_file = _bgzip_file(in_file, data["dirs"], config, needs_bgzip, needs_gunzip,
                                needs_convert)
     else:
@@ -363,19 +391,26 @@ def _bgzip_file(in_file, dirs, config, needs_bgzip, needs_gunzip, needs_convert)
                             (".gz" if not in_file.endswith(".gz") else ""))
     if not utils.file_exists(out_file):
         with file_transaction(config, out_file) as tx_out_file:
-            assert needs_bgzip
             bgzip = tools.get_bgzip_cmd(config)
-            in_file = utils.remote_cl_input(in_file)
+            is_remote = in_file.startswith(utils.SUPPORTED_REMOTES)
+            in_file = utils.remote_cl_input(in_file, unpack=needs_gunzip or needs_convert or needs_bgzip)
             if needs_convert:
                 in_file = fastq_convert_pipe_cl(in_file, {"config": config})
-            if needs_gunzip:
+            if needs_gunzip and not needs_convert:
                 gunzip_cmd = "gunzip -c {in_file} |".format(**locals())
                 bgzip_in = "/dev/stdin"
             else:
                 gunzip_cmd = ""
                 bgzip_in = in_file
-            do.run("{gunzip_cmd} {bgzip} -c {bgzip_in} > {tx_out_file}".format(**locals()),
-                   "bgzip input file")
+            if needs_bgzip:
+                do.run("{gunzip_cmd} {bgzip} -c {bgzip_in} > {tx_out_file}".format(**locals()),
+                       "bgzip input file")
+            elif is_remote:
+                bgzip = "| bgzip -c" if needs_convert else ""
+                do.run("cat {in_file} {bgzip} > {tx_out_file}".format(**locals()), "Get remote input")
+            else:
+                raise ValueError("Unexpected inputs: %s %s %s %s" % (in_file, needs_bgzip,
+                                                                     needs_gunzip, needs_convert))
     return out_file
 
 def _check_gzipped_input(in_file, grabix, needs_convert):
