@@ -1,6 +1,9 @@
 import os
 import sys
 import shutil
+import subprocess
+import contextlib
+from distutils.version import LooseVersion
 
 from bcbio.pipeline import config_utils
 from bcbio.distributed.transaction import file_transaction, tx_tmpdir
@@ -28,7 +31,9 @@ def align(fastq_file, pair_file, ref_file, names, align_dir, data):
 
     final_out = os.path.join(out_dir, "{0}.bam".format(names["sample"]))
     if file_exists(final_out):
-        return final_out
+        data = _update_data(final_out, out_dir, names, data)
+        return data
+
     star_path = config_utils.get_program("STAR", config)
     fastq = " ".join([fastq_file, pair_file]) if pair_file else fastq_file
     num_cores = config["algorithm"].get("num_cores", 1)
@@ -49,7 +54,7 @@ def align(fastq_file, pair_file, ref_file, names, align_dir, data):
     if strandedness == "unstranded":
         cmd += " --outSAMstrandField intronMotif "
 
-    if dd.get_rsem(data):
+    if dd.get_rsem(data) and not is_transcriptome_broken():
         cmd += " --quantMode TranscriptomeSAM "
 
     with tx_tmpdir(data) as tmp_dir:
@@ -60,9 +65,16 @@ def align(fastq_file, pair_file, ref_file, names, align_dir, data):
         with file_transaction(data, final_out) as tx_final_out:
             do.run(cmd.format(**locals()), run_message, None)
 
-    if dd.get_rsem(data):
+    data = _update_data(final_out, out_dir, names, data)
+    return data
+
+def _update_data(align_file, out_dir, names, data):
+    data = dd.set_work_bam(data, align_file)
+    data = dd.set_align_bam(data, align_file)
+    if dd.get_rsem(data) and not is_transcriptome_broken():
         transcriptome_file = _move_transcriptome_file(out_dir, names)
-    return final_out
+        data = dd.set_transcriptome_bam(data, transcriptome_file)
+    return data
 
 def _move_transcriptome_file(out_dir, names):
     out_file = os.path.join(out_dir, "{0}.transcriptome.bam".format(names["sample"]))
@@ -72,7 +84,6 @@ def _move_transcriptome_file(out_dir, names):
         shutil.move(tmp_file, out_file)
     return out_file
 
-
 def _read_group_option(names):
     rg_id = names["rg"]
     rg_sample = names["sample"]
@@ -114,3 +125,22 @@ def index(ref_file, out_dir, data):
                 shutil.rmtree(out_dir)
             shutil.move(tx_out_dir, out_dir)
     return out_dir
+
+def get_star_version():
+    cmd = "STAR --version"
+    subp = subprocess.Popen(cmd, stdout=subprocess.PIPE,
+                            stderr=subprocess.STDOUT,
+                            shell=True)
+    with contextlib.closing(subp.stdout) as stdout:
+        for line in stdout:
+            if "STAR_" in line:
+                version = line.split("STAR_")[1].strip()
+    return version
+
+def is_transcriptome_broken():
+    """
+    mapping to the transcriptome causes segfaults, but will be supported later
+    until it is fixed, skip this and use the fallback mapping instead
+    """
+    version = get_star_version()
+    return LooseVersion(version) >= LooseVersion("2.4.0g")
