@@ -143,7 +143,7 @@ class Variant2Pipeline(AbstractPipeline):
                                                              [x[0]["description"] for x in samples]]])
             with profile.report("alignment preparation", dirs):
                 samples = run_parallel("prep_align_inputs", samples)
-                samples = disambiguate.split(samples)
+                samples = run_parallel("disambiguate_split", [samples])
             with profile.report("alignment", dirs):
                 samples = run_parallel("process_alignment", samples)
                 samples = alignprep.merge_split_alignments(samples, run_parallel)
@@ -201,8 +201,10 @@ def _debug_samples(i, samples):
         print "  ", sample["description"], sample.get("region"), \
             utils.get_in(sample, ("config", "algorithm", "variantcaller")), \
             utils.get_in(sample, ("config", "algorithm", "jointcaller")), \
+            utils.get_in(sample, ("metadata", "batch")), \
             [x.get("variantcaller") for x in sample.get("variants", [])], \
-            sample.get("work_bam")
+            sample.get("work_bam"), \
+            sample.get("vrn_file")
 
 class SNPCallingPipeline(Variant2Pipeline):
     """Back compatible: old name for variant analysis.
@@ -284,7 +286,7 @@ class RnaseqPipeline(AbstractPipeline):
                         samples, config, dirs, "alignment",
                         multiplier=alignprep.parallel_multiplier(samples)) as run_parallel:
             with profile.report("alignment", dirs):
-                samples = disambiguate.split(samples)
+                samples = run_parallel("disambiguate_split", [samples])
                 samples = run_parallel("process_alignment", samples)
         with prun.start(_wres(parallel, ["samtools", "cufflinks"]),
                         samples, config, dirs, "rnaseqcount") as run_parallel:
@@ -292,8 +294,18 @@ class RnaseqPipeline(AbstractPipeline):
                 samples = disambiguate.resolve(samples, run_parallel)
             with profile.report("transcript assembly", dirs):
                 samples = rnaseq.assemble_transcripts(run_parallel, samples)
-            with profile.report("estimate expression", dirs):
-                samples = rnaseq.estimate_expression(samples, run_parallel)
+            with profile.report("estimate expression (threaded)", dirs):
+                samples = rnaseq.quantitate_expression_parallel(samples, run_parallel)
+        with prun.start(_wres(parallel, ["dexseq", "express"]), samples, config,
+                        dirs, "rnaseqcount-singlethread", max_multicore=1) as run_parallel:
+            with profile.report("estimate expression (single threaded)", dirs):
+                samples = rnaseq.quantitate_expression_noparallel(samples, run_parallel)
+        samples = rnaseq.combine_files(samples)
+        with prun.start(_wres(parallel, ["gatk"]), samples, config,
+                        dirs, "rnaseq-variation") as run_parallel:
+            with profile.report("RNA-seq variant calling", dirs):
+                samples = rnaseq.rnaseq_variant_calling(samples, run_parallel)
+
         with prun.start(_wres(parallel, ["picard", "fastqc", "rnaseqc", "kraken"]),
                         samples, config, dirs, "qc") as run_parallel:
             with profile.report("quality control", dirs):
@@ -314,10 +326,12 @@ class ChipseqPipeline(AbstractPipeline):
                                                              [x[0]["description"] for x in samples]]])
             samples = run_parallel("prepare_sample", samples)
             samples = run_parallel("trim_sample", samples)
-            samples = disambiguate.split(samples)
+            samples = run_parallel("disambiguate_split", [samples])
             samples = run_parallel("process_alignment", samples)
         with prun.start(_wres(parallel, ["picard", "fastqc"]),
                         samples, config, dirs, "persample") as run_parallel:
+            with profile.report("disambiguation", dirs):
+                samples = disambiguate.resolve(samples, run_parallel)
             samples = run_parallel("clean_chipseq_alignment", samples)
             samples = qcsummary.generate_parallel(samples, run_parallel)
         return samples
