@@ -17,7 +17,7 @@ from bcbio.log import logger
 from bcbio.illumina import flowcell
 from bcbio.pipeline import alignment, config_utils, genome
 from bcbio.provenance import diagnostics, programs, versioncheck
-from bcbio.variation import effects, genotype, population, joint
+from bcbio.variation import effects, genotype, population, joint, vcfutils
 from bcbio.variation.cortex import get_sample_name
 from bcbio.bam.fastq import open_fastq
 
@@ -125,7 +125,8 @@ def add_reference_resources(data):
     ref_loc = utils.get_in(data, ("config", "resources", "species", "dir"),
                            utils.get_in(data, ("reference", "fasta", "base")))
     data["genome_resources"] = genome.get_resources(data["genome_build"], ref_loc)
-    data["reference"]["snpeff"] = effects.get_snpeff_files(data)
+    if effects.get_type(data) == "snpeff":
+        data["reference"]["snpeff"] = effects.get_snpeff_files(data)
     alt_genome = utils.get_in(data, ("config", "algorithm", "validate_genome_build"))
     if alt_genome:
         data["reference"]["alt"] = {alt_genome:
@@ -327,7 +328,7 @@ def _check_quality_format(items):
         fastq_file = next((file for file in item.get('files', []) if
                            any([ext for ext in fastq_extensions if ext in file])), None)
 
-        if fastq_file and specified_format:
+        if fastq_file and specified_format and not fastq_file.startswith(utils.SUPPORTED_REMOTES):
             fastq_format = _detect_fastq_format(fastq_file)
             detected_encodings = set([SAMPLE_FORMAT[x] for x in fastq_format])
             if detected_encodings:
@@ -497,6 +498,8 @@ def _run_info_from_yaml(fc_dir, run_info_yaml, config, sample_names):
         item["algorithm"] = _add_algorithm_defaults(item["algorithm"])
         item["rgnames"] = prep_rg_names(item, config, fc_name, fc_date)
         item["test_run"] = global_config.get("test_run", False)
+        if item.get("vrn_file") and isinstance(item["vrn_file"], basestring):
+            item["vrn_file"] = vcfutils.bgzip_and_index(genome.abs_file_paths(item["vrn_file"]), config)
         item = _clean_metadata(item)
         item = _clean_algorithm(item)
         # Add any global resource specifications
