@@ -4,7 +4,7 @@ import toolz as tz
 
 from bcbio.log import logger
 from bcbio.variation.genotype import variant_filtration, get_variantcaller
-from bcbio.variation import effects
+from bcbio.variation import effects, prioritize
 
 # ## Genotyping
 
@@ -15,7 +15,7 @@ def postprocess_variants(data):
     logger.info("Finalizing variant calls: %s" % cur_name)
     if data.get("align_bam") and data.get("vrn_file"):
         logger.info("Calculating variation effects for %s" % cur_name)
-        effect_todo = tz.get_in(("config", "algorithm", "effects"), data, "snpeff")
+        effect_todo = effects.get_type(data)
         if effect_todo:
             if effect_todo == "snpeff":
                 ann_vrn_file = effects.snpeff_effects(data)
@@ -29,4 +29,6 @@ def postprocess_variants(data):
         data["vrn_file"] = variant_filtration(data["vrn_file"], data["sam_ref"],
                                               tz.get_in(("genome_resources", "variation"), data, {}),
                                               data)
+        logger.info("Prioritization for %s" % cur_name)
+        data["vrn_file"] = prioritize.handle_vcf_calls(data["vrn_file"], data)
     return [[data]]
