@@ -57,6 +57,7 @@ def _run_delly(bam_files, chrom, sv_type, ref_file, work_dir, items):
                 vcfutils.write_empty_vcf(tx_out_file, samples=names)
             else:
                 exclude = ["-x", _delly_exclude_file(items, out_file, chrom)]
+                map_qual = ["--map-qual", "1"]
                 cmd = ["delly", "-t", sv_type, "-g", ref_file, "-o", tx_out_file] + exclude + bam_files
                 multi_cmd = "export OMP_NUM_THREADS=%s && export LC_ALL=C && " % cores
                 try:
@@ -115,13 +116,18 @@ def _prep_subsampled_bams(data, work_dir):
 
     https://groups.google.com/d/msg/delly-users/xmia4lwOd1Q/uaajoBkahAIJ
 
-    Subsamples correctly aligned reads to 50 million based on speedseq defaults and
+    Subsamples correctly aligned reads to 100 million based on speedseq defaults and
     evaluations on NA12878 whole genome data:
 
     https://github.com/cc2qe/speedseq/blob/ca624ba9affb0bd0fb88834ca896e9122639ec94/bin/speedseq#L1102
+
+    XXX Currently does not downsample as new versions do not get good sensitivity with
+    downsampled BAMs.
     """
     full_bam, sr_bam, disc_bam = sshared.get_split_discordants(data, work_dir)
-    ds_bam = bam.downsample(full_bam, data, 5e7, read_filter="-F 'not secondary_alignment and proper_pair'",
+    return [full_bam]
+
+    ds_bam = bam.downsample(full_bam, data, 1e8, read_filter="-F 'not secondary_alignment and proper_pair'",
                             always_run=True, work_dir=work_dir)
     out_bam = "%s-final%s" % utils.splitext_plus(ds_bam)
     if not utils.file_exists(out_bam):
@@ -189,7 +195,7 @@ def run(items):
                                  in itertools.product(sshared.get_sv_chroms(items, exclude_file), sv_types)],
                                 config, parallel)
     out_file = "%s.vcf.gz" % sshared.outname_from_inputs(bytype_vcfs)
-    combo_vcf = vcfutils.combine_variant_files(bytype_vcfs, out_file, ref_file, items[0]["config"])
+    combo_vcf = vcfutils.combine_variant_files(bytype_vcfs, out_file, ref_file, config)
     out = []
     for data in items:
         if "sv" not in data:
