@@ -38,7 +38,7 @@ def _run_lumpy(full_bams, sr_bams, disc_bams, work_dir, items):
                 full_bams = ",".join(full_bams)
                 sr_bams = ",".join(sr_bams)
                 disc_bams = ",".join(disc_bams)
-                exclude = "-x %s" % sv_exclude_bed if sv_exclude_bed else ""
+                exclude = "-x %s" % sv_exclude_bed if utils.file_exists(sv_exclude_bed) else ""
                 ref_file = dd.get_ref_file(items[0])
                 # use our bcbio python for runs within speedseq
                 curpython_dir = os.path.dirname(sys.executable)
@@ -132,7 +132,8 @@ def _bedpe_to_vcf(bedpe_file, sconfig_file, items):
                     cmd = [sys.executable, tovcf_script, "-c", sconfig_file, "-f", dd.get_ref_file(items[0]),
                            "-t", "LUMPY", "-b", bedpe_file, "-o", tx_raw_file]
                     do.run(cmd, "Convert lumpy bedpe output to VCF")
-            prep_file = vcfutils.sort_by_ref(raw_file, items[0])
+            clean_file = _clean_lumpy_vcf(raw_file, items[0])
+            prep_file = vcfutils.sort_by_ref(clean_file, items[0])
             if not utils.file_exists(out_nogzip):
                 utils.symlink_plus(prep_file, out_nogzip)
         out_file = vcfutils.bgzip_and_index(out_nogzip, items[0]["config"])
@@ -168,10 +169,29 @@ def _filter_by_bedpe(vcf_file, bedpe_file, data):
             vcfutils.bgzip_and_index(nogzip_out_file, data["config"])
     return out_file
 
+def _clean_lumpy_vcf(vcf_file, data):
+    """Remove problem calls in the output VCF with missing alleles.
+    """
+    assert not vcf_file.endswith(".gz")
+    out_file = "%s-clean%s" % utils.splitext_plus(vcf_file)
+    if not utils.file_exists(out_file):
+        with file_transaction(data, out_file) as tx_out_file:
+            with open(tx_out_file, "w") as out_handle:
+                with utils.open_gzipsafe(vcf_file) as in_handle:
+                    for line in in_handle:
+                        if not line.startswith("#"):
+                            parts = line.split("\t")
+                            # Problem breakends can have empty alleles when at contig ends
+                            if not parts[3].strip():
+                                parts[3] = "N"
+                            line = "\t".join(parts)
+                        out_handle.write(line)
+    return out_file
+
 def run(items):
     """Perform detection of structural variations with lumpy, using bwa-mem alignment.
     """
-    if not all(utils.get_in(data, ("config", "algorithm", "aligner")) == "bwa" for data in items):
+    if not all(utils.get_in(data, ("config", "algorithm", "aligner")) in ["bwa", False, None] for data in items):
         raise ValueError("Require bwa-mem alignment input for lumpy structural variation detection")
     work_dir = utils.safe_makedir(os.path.join(items[0]["dirs"]["work"], "structural", items[0]["name"][-1],
                                                "lumpy"))
