@@ -60,6 +60,7 @@ def _get_files_rnaseq(sample):
     out = _maybe_add_counts(algorithm, sample, out)
     out = _maybe_add_cufflinks(algorithm, sample, out)
     out = _maybe_add_oncofuse(algorithm, sample, out)
+    out = _maybe_add_rnaseq_variant_file(algorithm, sample, out)
     return _add_meta(out, sample)
 
 def _get_files_chipseq(sample):
@@ -102,11 +103,19 @@ def _get_files_variantcall(sample):
 
 def _maybe_add_validate(algorith, sample, out):
     for i, plot in enumerate(tz.get_in(("validate", "grading_plots"), sample, [])):
+        ptype = os.path.splitext(plot)[-1].replace(".", "")
         out.append({"path": plot,
-                    "type": "pdf",
+                    "type": ptype,
                     "ext": "validate%s" % ("" if i == 0 else "-%s" % (i + 1))})
     return out
 
+def _maybe_add_rnaseq_variant_file(algorithm, sample, out):
+    if sample.get("vrn_file"):
+        out.append({"path": sample.get("vrn_file"),
+                    "type": "vcf",
+                    "ext": "vcf"})
+    return out
+
 def _maybe_add_variant_file(algorithm, sample, out):
     if sample.get("align_bam") is not None and sample.get("vrn_file"):
         for x in sample["variants"]:
@@ -129,13 +138,21 @@ def _maybe_add_sv(algorithm, sample, out):
                             "ext": "%s-sample" % svcall["variantcaller"],
                             "variantcaller": svcall["variantcaller"]})
             if "validate" in svcall:
-                for vkey, vext in [("csv", "csv"), ("plot", "pdf")]:
+                for vkey in ["csv", "plot", "df"]:
                     vfile = tz.get_in(["validate", vkey], svcall)
                     if vfile:
-                        out.append({"path": vfile,
-                                    "type": vext,
-                                    "ext": "%s-validate" % svcall["variantcaller"],
-                                    "variantcaller": svcall["variantcaller"]})
+                        to_u = []
+                        if isinstance(vfile, dict):
+                            for svtype, fname in vfile.items():
+                                to_u.append((fname, "-%s" % svtype))
+                        else:
+                            to_u.append((vfile, "-%s" % vkey if vkey in ["df"] else ""))
+                        for vfile, ext in to_u:
+                            vext = os.path.splitext(vfile)[-1].replace(".", "")
+                            out.append({"path": vfile,
+                                        "type": vext,
+                                        "ext": "%s-sv-validate%s" % (svcall["variantcaller"], ext),
+                                        "variantcaller": svcall["variantcaller"]})
     return out
 
 def _get_variant_file(x, key):
@@ -293,5 +310,11 @@ def _get_files_project(sample, upload_config):
         out.append({"path": sample["assembled_gtf"]})
     if dd.get_dexseq_counts(sample):
         out.append({"path": dd.get_dexseq_counts(sample)})
+    if dd.get_express_counts(sample):
+        out.append({"path": dd.get_express_counts(sample)})
+    if dd.get_express_fpkm(sample):
+        out.append({"path": dd.get_express_fpkm(sample)})
+    if dd.get_express_tpm(sample):
+        out.append({"path": dd.get_express_tpm(sample)})
 
     return _add_meta(out, config=upload_config)
