@@ -8,6 +8,7 @@ import toolz as tz
 
 from bcbio import utils
 from bcbio.distributed.split import grouped_parallel_split_combine
+from bcbio.pipeline import datadict as dd
 from bcbio.pipeline import region
 from bcbio.variation import gatk, gatkfilter, multi, phasing, ploidy, vfilter
 
@@ -68,6 +69,11 @@ def combine_multiple_callers(samples):
                                     "vrn_file_batch": data.get("vrn_file_batch"),
                                     "validate": data.get("validate"),
                                     "do_upload": False})
+            if not jointcaller and not variantcaller:
+                ready_calls.append({"variantcaller": "precalled",
+                                    "vrn_file": data.get("vrn_file"),
+                                    "validate": data.get("validate"),
+                                    "do_upload": False})
         final = callgroup[0][-1]
         def orig_variantcaller_order(x):
             try:
@@ -149,6 +155,7 @@ def parallel_variantcall_region(samples, run_parallel):
             added = True
             to_process.append([add])
         if not added:
+            data = _handle_precalled(data)
             extras.append([data])
     split_fn = _split_by_ready_regions(".vcf.gz", "work_bam", get_variantcaller)
     samples = _collapse_by_bam_variantcaller(
@@ -158,6 +165,22 @@ def parallel_variantcall_region(samples, run_parallel):
                                        "vrn_file", ["region", "sam_ref", "config"]))
     return extras + samples
 
+def _handle_precalled(data):
+    """Symlink in external pre-called variants fed into analysis.
+    """
+    if data.get("vrn_file"):
+        vrn_file = data["vrn_file"]
+        if isinstance(vrn_file, (list, tuple)):
+            assert len(vrn_file) == 1
+            vrn_file = vrn_file[0]
+        precalled_dir = utils.safe_makedir(os.path.join(dd.get_work_dir(data), "precalled"))
+        ext = utils.splitext_plus(vrn_file)[-1]
+        orig_file = os.path.abspath(vrn_file)
+        our_vrn_file = os.path.join(precalled_dir, "%s-precalled%s" % (dd.get_sample_name(data), ext))
+        utils.symlink_plus(orig_file, our_vrn_file)
+        data["vrn_file"] = our_vrn_file
+    return data
+
 def handle_multiple_callers(data, key, default=None):
     """Split samples that potentially require multiple variant calling approaches.
     """
@@ -170,14 +193,27 @@ def handle_multiple_callers(data, key, default=None):
         out = []
         for caller in callers:
             base = copy.deepcopy(data)
-            base["config"]["algorithm"]["orig_%s" % key] = \
-              base["config"]["algorithm"][key]
+            if not base["config"]["algorithm"].get("orig_%s" % key):
+                base["config"]["algorithm"]["orig_%s" % key] = \
+                  base["config"]["algorithm"][key]
             base["config"]["algorithm"][key] = caller
+            # if splitting by variant caller, also split by jointcaller
+            if key == "variantcaller":
+                jcallers = get_variantcaller(data, "jointcaller", [])
+                if isinstance(jcallers, basestring):
+                    jcallers = [jcallers]
+                if jcallers:
+                    base["config"]["algorithm"]["orig_jointcaller"] = jcallers
+                    jcallers = [x for x in jcallers if x.startswith(caller)]
+                    if jcallers:
+                        base["config"]["algorithm"]["jointcaller"] = jcallers[0]
+                    else:
+                        base["config"]["algorithm"]["jointcaller"] = False
             out.append(base)
         return out
 
 def get_variantcallers():
-    from bcbio.variation import freebayes, cortex, samtools, varscan, mutect, platypus, scalpel, vardict
+    from bcbio.variation import freebayes, cortex, samtools, varscan, mutect, platypus, scalpel, vardict, qsnp
     return {"gatk": gatk.unified_genotyper,
             "gatk-haplotype": gatk.haplotype_caller,
             "freebayes": freebayes.run_freebayes,
@@ -187,7 +223,8 @@ def get_variantcallers():
             "mutect": mutect.mutect_caller,
             "platypus": platypus.run,
             "scalpel": scalpel.run_scalpel,
-            "vardict": vardict.run_vardict}
+            "vardict": vardict.run_vardict,
+            "qsnp": qsnp.run_qsnp}
 
 def variantcall_sample(data, region=None, align_bams=None, out_file=None):
     """Parallel entry point for doing genotyping of a region of a sample.
